from setuptools import setup

setup(
    name='sokolpackage',
    version='0.1.0',    
    description='A example Python package',
    url='',
    author='Alexandr Sokolov',
    author_email='sokolov-19.07@yandex.ru',
    packages=['sokolpackage'],
    requires=['pandas'],
)
